==> zesty.zbs_api-1.0.2020.11.17.2-py3-none-any.whl: zesty/models/hf_interface.py <==
from __future__ import annotations
from abc import ABC, abstractmethod
import enum

from typing import TYPE_CHECKING, Dict

if TYPE_CHECKING:
    from zesty.actions import ZBSAction


class SpecialInstructions:
    """
    Constructor for special instructions with optional parameters:
    * dev_id: identify the device for the filesystem to which the action is attached
    * size: specify the capacity for a new device or the additional capacity when extending a device
    * sub_actions: when an action implements multiple actions, specify a dictionary:
        -- { int(specifies action priorities): list(actions that can be run in parallel) }
        -- Actions in a list keyed to a higher order cannot start until all Actions of lower orders complete
    """
    def __init__(self, dev_id: str = None, size: int = None, sub_actions: Dict[int, Dict[str, IActionHF]] = None):
        self.dev_id = dev_id
        self.size = size
        self.sub_actions = sub_actions


class IActionHF(ABC):

    class Status(enum.Enum):
        NEW = 1
        PENDING = 2
        RUNNING = 3
        CANCELED = 4

    @abstractmethod
    def get_action_id(self) -> str:
        raise NotImplementedError(
            "ActionHF 'get_action_id' is abstract, please implement")

    @abstractmethod
    def get_action_type(self) -> str:
        raise NotImplementedError(
            "ActionHF 'get_action_type' is abstract, please implement")

    @abstractmethod
    def get_status(self) -> Status:
        raise NotImplementedError(
            "ActionHF 'get_status' is abstract, please implement")

    @abstractmethod
    def set_status(self, status: Status):
        raise NotImplementedError(
            "ActionHF 'set_status' is abstract, please implement")

    @abstractmethod
    def get_special_instructions(self) -> SpecialInstructions:
        raise NotImplementedError(
            "ActionHF 'get_special_instructions' is abstract, please implement")

    @abstractmethod
    def set_special_instructions(self, special_instructions: SpecialInstructions):
        raise NotImplementedError(
            "ActionHF 'set_special_instructions' is abstract, please implement")


class IDeviceHF(ABC):

    @abstractmethod
    def get_dev_id(self) -> str:
        raise NotImplementedError(
            "DeviceHF 'get_dev_id' is abstract, please implement")

    @abstractmethod
    def get_size(self) -> int:
        raise NotImplementedError(
            "DeviceHF 'get_size' is abstract, please implement")

    @abstractmethod
    def get_usage(self) -> int:
        raise NotImplementedError(
            "DeviceHF 'get_usage' is abstract, please implement")

    @abstractmethod
    def get_unlock_ts(self) -> int:
        raise NotImplementedError(
            "DeviceHF 'get_unlock_ts' is abstract, please implement")


class IFileSystemHF(ABC):

    @abstractmethod
    def get_fs_id(self) -> str:
        raise NotImplementedError(
            "FileSystemHF 'get_fs_id' is abstract, please implement")

    @abstractmethod
    def get_devices(self) -> Dict[str, IDeviceHF]:
        raise NotImplementedError(
            "FileSystemHF 'get_devices' is abstract, please implement")

    @abstractmethod
    def get_existing_actions(self) -> Dict[str, IActionHF]:
        raise NotImplementedError(
            "FileSystemHF 'get_existing_actions' is abstract, please implement")

==> zesty.zbs_api-1.0.2021.10.28.1635430662-py3-none-any.whl: zesty/models/hf_interface.py <==
from abc import ABC, abstractmethod
import enum

from typing import TYPE_CHECKING, Dict

if TYPE_CHECKING:
    from ..actions import ZBSAction
    pass


class ISpecialInstructions(ABC):
    pass


class IActionHF(ABC):
    class Status(enum.Enum):
        NEW = 1
        PENDING = 2
        RUNNING = 3
        CANCELED = 4
        READY = 5

    @abstractmethod
    def get_action_id(self) -> str:
        raise NotImplementedError(
            "ActionHF 'get_action_id' is abstract, please implement")

    @abstractmethod
    def get_action_type(self) -> str:
        raise NotImplementedError(
            "ActionHF 'get_action_type' is abstract, please implement")

    @abstractmethod
    def get_status(self) -> Status:
        raise NotImplementedError(
            "ActionHF 'get_status' is abstract, please implement")

    @abstractmethod
    def set_status(self, status: Status):
        raise NotImplementedError(
            "ActionHF 'set_status' is abstract, please implement")

    @abstractmethod
    def get_special_instructions(self) -> ISpecialInstructions:
        raise NotImplementedError(
            "ActionHF 'get_special_instructions' is abstract, please implement")

    @abstractmethod
    def set_special_instructions(self, special_instructions: ISpecialInstructions):
        raise NotImplementedError(
            "ActionHF 'set_special_instructions' is abstract, please implement")


class IDeviceHF(ABC):

    @abstractmethod
    def get_dev_id(self) -> str:
        raise NotImplementedError(
            "DeviceHF 'get_dev_id' is abstract, please implement")

    @abstractmethod
    def get_size(self) -> int:
        raise NotImplementedError(
            "DeviceHF 'get_size' is abstract, please implement")

    @abstractmethod
    def get_usage(self) -> int:
        raise NotImplementedError(
            "DeviceHF 'get_usage' is abstract, please implement")

    @abstractmethod
    def get_unlock_ts(self) -> int:
        raise NotImplementedError(
            "DeviceHF 'get_unlock_ts' is abstract, please implement")

class IFileSystemHF(ABC):

    @abstractmethod
    def get_fs_id(self) -> str:
        raise NotImplementedError(
            "IFileSystemHF 'get_fs_id' is abstract, please implement")

    @abstractmethod
    def get_devices(self) -> Dict[str, IDeviceHF]:
        raise NotImplementedError(
            "IFileSystemHF 'get_devices' is abstract, please implement")

    @abstractmethod
    def get_existing_actions(self) -> Dict[str, IActionHF]:
        raise NotImplementedError(
            "IFileSystemHF 'get_existing_actions' is abstract, please implement")
